==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
var OnCollapsedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OnCollapsedEventArgsDescriptionMetadata, _super);
    function OnCollapsedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnCollapsedEventArgsDescriptionMetadata.b = function (a) {
        if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
            OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        if (a.g(OnCollapsedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnCollapsedEventArgsDescriptionMetadata.d = function (a) {
        OnCollapsedEventArgsDescriptionMetadata.b(a);
        a.u("OnCollapsedEventArgs", function () { return new OnCollapsedEventArgsDescription(); });
        a.t("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
}(Base));
export { OnCollapsedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
var OnCollapsedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OnCollapsedEventArgsDescriptionMetadata, _super);
    function OnCollapsedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnCollapsedEventArgsDescriptionMetadata.b = function (a) {
        if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
            OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        if (a.j(OnCollapsedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnCollapsedEventArgsDescriptionMetadata.d = function (a) {
        OnCollapsedEventArgsDescriptionMetadata.b(a);
        a.aa("OnCollapsedEventArgs", function () { return new OnCollapsedEventArgsDescription(); });
        a.z("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
}(Base));
export { OnCollapsedEventArgsDescriptionMetadata };
